==> dl.php?src=linea21_1_7.zip: linea21/languages/es/lang_comment.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage es
 * @author Simon Georget <simon@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 * @todo translation
 */

// @todo translation

$lang['comment']['section'] = "Comments";

/*
 * Comment
 */
$lang['comment']['nocomment_yet']= "No one has commented yet.";
$lang['comment']['add']= "Add a new comment";
$lang['comment']['name']= "Your name";
$lang['comment']['email']="Your email (not displayed)";
$lang['comment']['website']="Your website";
$lang['comment']['body']="Your message";
$lang['comment']['email_notification']="Receive an email when new comments are posted.";
$lang['comment']['logged-in_post']="You are logged-in as %s.";
$lang['comment']['go_to']="See comments";
$lang['comment']['number']="%s comment(s)";
$lang['comment']['comments']="comment(s)";
$lang['comment']['successful']="Your comment has been submited successfully.";
$lang['comment']['moderation_msg']="Comments have to be approved first. Your message will appear after being approved by an administrator.";
$lang['comment']['only_registered']="Only registered users can add comments. If you already have an account, please <a href=\"%s\">log-in</a>.";
$lang['comment']['to_moderate']="Comment is waiting for an administrator approval";
$lang['comment']['posted_in']="posted in";
$lang['comment']['approve']="approve";
$lang['comment']['disapprove']="disapprove";
$lang['comment']['approved']="approved";
$lang['comment']['disapproved']="disapproved";
$lang['comment']['all_approved']="approved";
$lang['comment']['all_disapproved']="disapproved";
$lang['comment']['delete']="delete";
$lang['comment']['registered_user']="[registered]";

$lang['comment']['published']="Published";
$lang['comment']['awaiting']="Waiting approval";

$lang['comment_map']['news']="news";
$lang['comment_map']['project']="project";
$lang['comment_map']['workgroups']="workgroup";
$lang['comment_map']['publication']="publication";
$lang['comment_map']['report']="report";
$lang['comment_map']['indicator']="indicator";
$lang['comment_map']['files']="file";
$lang['comment_map']['contribute']="contribution";

/*	nommage rubrique module
 *  	*/
$lang['comment']['list']= 'View comments';
$lang['comment']['det']= 'Comment detail';
$lang['comment']['unsubscribe_title']='Unsubscribe to email notification';
$lang['comment']['unsubscribe_successful']="You will not receive email notification anymore when new comments are posted.";

/*	check integrité des données
 *  	*/
$lang['comment']['no_name']="Please, enter your name.";
$lang['comment']['no_email']="Please, enter your email.";
$lang['comment']['no_body']="Please, enter your message.";


/*	divers
 *  	*/
$lang['comment']['nb_total']="%d comments are stored in the database.";
$lang['comment']['status_filter']='Status filter';
$lang['comment']['module_filter']='Module filter';
$lang['comment']['all']='Diplay the full list';
$lang['comment']['noresult']='No comments for given criterion ';


/*	public
 *  	*/
$lang['comment']['mail_subject_newcomment']='%s - a new comment has been posted';
$lang['comment']['mail_subject_moderate']='%s - Moderate a new comment';
$lang['comment']['mail_body1']='%s has posted a new comment in %s';
$lang['comment']['mail_body2']='Moderate';
$lang['comment']['mail_body3']='Your receive this message because you choose to be notified on new comments. To stop receiving email notification, follow this link : ';
$lang['comment']['mail_body_auth'] = 'Important : You must be logged-in to access the page.';

/*	public
 *  	*/

$lang['comment']['name2']='comment(s)';

$lang['comment']['contribute_item']='Contributions';
$lang['comment']['contribute_title']='Give your opinion!';
$lang['comment']['contribute_chapo']='The website gives you the ability to pronounce yourself regarding ou policy. %s contributions have been sent to us.';


/*	rubrique d'aide
 *  	*/
$lang['comment']['help_1']='You can delete any comment by clicking on the delete icon linked in.';
$lang['comment']['help_2']='You can approve any comment by clicking on the approval icon linked in.';
$lang['comment']['help_3']='You can disapprove any comment by clicking on the disapproval icon linked in.';

?>

==> dl.php?src=linea21_2_0_0.zip: linea21/languages/es/lang_comment.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Simon Georget <simon@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 * @todo translation
 */

// @todo translation

$lang['comment']['section'] = "Comments";

/*
 * Comment
 */
$lang['comment']['nocomment_yet']= "No one has commented yet.";
$lang['comment']['add']= "Add a new comment";
$lang['comment']['name']= "Your name";
$lang['comment']['email']="Your email (not displayed)";
$lang['comment']['website']="Your website";
$lang['comment']['body']="Your message";
$lang['comment']['email_notification']="Receive an email when new comments are posted.";
$lang['comment']['logged-in_post']="You are logged-in as %s.";
$lang['comment']['go_to']="See comments";
$lang['comment']['number']="%s comment(s)";
$lang['comment']['comments']="comment(s)";
$lang['comment']['successful']="Your comment has been submited successfully.";
$lang['comment']['moderation_msg']="Comments have to be approved first. Your message will appear after being approved by an administrator.";
$lang['comment']['only_registered']="Only registered users can add comments. If you already have an account, please <a href=\"%s\">log-in</a>.";
$lang['comment']['to_moderate']="Comment is waiting for an administrator approval";
$lang['comment']['posted_in']="posted in";
$lang['comment']['approve']="approve";
$lang['comment']['disapprove']="disapprove";
$lang['comment']['approved']="approved";
$lang['comment']['disapproved']="disapproved";
$lang['comment']['all_approved']="approved";
$lang['comment']['all_disapproved']="disapproved";
$lang['comment']['delete']="delete";
$lang['comment']['registered_user']="[registered]";

$lang['comment']['published']="Published";
$lang['comment']['awaiting']="Waiting approval";

$lang['comment_map']['news']="news";
$lang['comment_map']['project']="project";
$lang['comment_map']['workgroups']="workgroup";
$lang['comment_map']['publication']="publication";
$lang['comment_map']['report']="report";
$lang['comment_map']['indicator']="indicator";
$lang['comment_map']['files']="file";
$lang['comment_map']['contribute']="contribution";

/*	nommage rubrique module
 *  	*/
$lang['comment']['list']= 'View comments';
$lang['comment']['det']= 'Comment detail';
$lang['comment']['unsubscribe_title']='Unsubscribe to email notification';
$lang['comment']['unsubscribe_successful']="You will not receive email notification anymore when new comments are posted.";

/*	check integrité des données
 *  	*/
$lang['comment']['no_name']="Please, enter your name.";
$lang['comment']['no_email']="Please, enter your email.";
$lang['comment']['no_body']="Please, enter your message.";


/*	divers
 *  	*/
$lang['comment']['nb_total']="%d comments are stored in the database.";
$lang['comment']['status_filter']='Status filter';
$lang['comment']['module_filter']='Module filter';
$lang['comment']['all']='Diplay the full list';
$lang['comment']['noresult']='No comments for given criterion ';


/*	public
 *  	*/
$lang['comment']['mail_subject_newcomment']='A new comment has been posted - %s';
$lang['comment']['mail_subject_moderate']='Moderate a new comment - %s';
$lang['comment']['mail_body1']='%s has posted a new comment in %s';
$lang['comment']['mail_body2']='Moderate';
$lang['comment']['mail_body3']='Your receive this message because you choose to be notified on new comments. To stop receiving email notification, follow this link : ';
$lang['comment']['mail_body_auth'] = 'Important : You must be logged-in to access the page.';

/*	public
 *  	*/

$lang['comment']['name2']='comment(s)';

$lang['comment']['contribute_item']='Contributions';
$lang['comment']['contribute_title']='Give your opinion!';
$lang['comment']['contribute_chapo']='The website gives you the ability to pronounce yourself regarding ou policy. %s contributions have been sent to us.';


/*	rubrique d'aide
 *  	*/
$lang['comment']['help_1']='You can delete any comment by clicking on the delete icon linked in.';
$lang['comment']['help_2']='You can approve any comment by clicking on the approval icon linked in.';
$lang['comment']['help_3']='You can disapprove any comment by clicking on the disapproval icon linked in.';

?>
